# TOPSIS
### BY: Pranjal Arora, 102003402, 3COE-16

TOPSIS is the Technique for Order of Preference by Similarity to Ideal Solution, and it is a multi-criteria decision analysis method. It is based on the fundamental premise that the best solution has the shortest distance from the positive-ideal solution, and the longest distance from the negative-ideal one. 
The method is used in the business across various industries, every time an analytical decision needs to be made, based on collected data.
Following is a package, coded in Python, to implement the Topsis Algorithm.

### Installation- USER MANUAL

1. Topsis-Pranjal-102003402 requires [Python3](https://www.python.org/) to run.
2. Other dependencies that come installed with this package are :-
---pandas
---numpy
---logging
3. Package listed on PyPI:- https://pypi.org/project/Topsis-Pranjal-102003402/ 
4. Use the following command to install this package:-
```sh
pip install Topsis-Pranjal-102003402
```
5. Now open the Python shell/IDE and import this package.


### License

MIT




